@@ -21,19 +21,22 @@
  */
 
 #include "config.h"
-#include <string.h>
-#include <stdlib.h>
-#include <sys/time.h>
-#include <gdk/gdkwindow.h>
-#include <gdk/gdkx.h>
-#include <gtk/gtk.h>
-#include <libbonobo.h>
 #include "magnifier.h"
 #include "magnifier-private.h"
 #include "zoom-region.h"
-#include "gmag-events.h"
+#include "gmag-graphical-server.h"
 #include "GNOME_Magnifier.h"
 
+#include <string.h>
+#include <stdlib.h>
+#include <sys/time.h>
+
+#include <gdk/gdkwindow.h>
+#include <gdk/gdkx.h>
+#include <gtk/gtk.h>
+
+#include <libbonobo.h>
+
 #define ENV_STRING_MAX_SIZE 128
 
 GNOME_Magnifier_ZoomRegion zoom_region;
@@ -475,13 +478,18 @@ main (int argc, char** argv)
   fprintf (stderr, "initial viewport %d %d\n", (int) screen_width,
 	   (int) screen_height);
 
-  init_rect_bounds (viewport, x, y, x + screen_width, y + screen_height);
-  viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds, viewport);
   
-  bonobo_pbclient_set_value (properties, "target-display-bounds",
-			     viewport_any,
-			     &ev);
-  bonobo_arg_release (viewport_any);
+  if (global_options.vertical_split || global_options.horizontal_split ||
+      global_options.fullscreen) {
+	  init_rect_bounds (viewport, x, y, x + screen_width,
+			    y + screen_height);
+	  viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds,
+					      viewport);
+  
+	  bonobo_pbclient_set_value (properties, "target-display-bounds",
+				     viewport_any, &ev);
+	  bonobo_arg_release (viewport_any);
+  }
 
   if (global_options.vertical_split || global_options.horizontal_split) 
   {
@@ -516,7 +524,9 @@ main (int argc, char** argv)
   {
 	  int scroll_policy;
 	  
-	  init_rect_bounds (roi, 0, 0, 100, 100);
+	  init_rect_bounds (roi, 0, 0,
+			    screen_width / global_options.zoom_factor,
+			    screen_height / global_options.zoom_factor);
 	  init_rect_bounds (viewport, 0, 0, screen_width, screen_height);
 	  zoom_region =
 		  GNOME_Magnifier_Magnifier_createZoomRegion (
@@ -594,7 +604,7 @@ main (int argc, char** argv)
   else
   {
 	  if (global_options.ignore_damage ||
-	      !gmag_events_source_has_damage_extension (magnifier)) 
+	      !gmag_gs_source_has_damage_extension (magnifier)) 
 	  {
 	  	  refresh_handle = g_timeout_add (
 	  		  global_options.refresh_time,
